@@ -15,7 +15,7 @@ logging.basicConfig(level=logging.DEBUG)
 logging.getLogger('urllib3').setLevel(logging.INFO)
 
 PRIVATE_TEST_KEY = 0x973f69bcd654b264759170724e1e30ccd2e75fc46b7993fd24ce755f0a8c24d0
-PUBLIC_ADDRESS = '0x5288fec4153b702430771dfac8aed0b21cafca4344dae0d47b97f0bf532b3306'
+PUBLIC_KEY = '0x5288fec4153b702430771dfac8aed0b21cafca4344dae0d47b97f0bf532b3306'
 
 
 PRIVATE_TEST_KEY_TEXT = """
@@ -38,12 +38,15 @@ def test_account_info():
         'private_bytes': to_bytes(PRIVATE_TEST_KEY),
         'private_text': PRIVATE_TEST_KEY_TEXT,
         'private_password': PRIVATE_TEST_KEY_PASSWORD,
-        'address': PUBLIC_ADDRESS
+        'public_key': PUBLIC_KEY
     }
 
 @pytest.fixture(scope='module')
-def test_account(test_account_info):
-    return Account.create_from_bytes(test_account_info['private_bytes'])
+def test_account(convex, test_account_info):
+    import_account = Account.import_from_bytes(test_account_info['private_bytes'])
+    account = convex.create_account(import_account)
+    convex.topup_account(account)
+    return account
 
 @pytest.fixture(scope='module')
 def convex_url():
@@ -56,6 +59,6 @@ def convex(convex_url):
 
 @pytest.fixture(scope='module')
 def other_account(convex):
-    account = Account.create_new()
+    account = convex.create_account()
     convex.topup_account(account)
     return account
