@@ -13,7 +13,7 @@ from eth_utils import add_0x_prefix
 from convex_api.account import Account
 from convex_api.convex_api import ConvexAPI
 from convex_api.exceptions import ConvexAPIError
-
+from convex_api.utils import to_address
 
 def test_convex_recursion(convex, test_account):
     chain_length = 4
@@ -35,7 +35,7 @@ def test_convex_recursion(convex, test_account):
 """
         convex.topup_account(test_account)
         result = convex.send(contract, test_account)
-        address_list.append(add_0x_prefix(result['value']))
+        address_list.append(to_address(result['value']))
     for index in range(0, chain_length):
         next_index = index + 1
         if next_index == chain_length:
@@ -82,7 +82,7 @@ def test_schedule_transfer(convex, test_account, other_account):
     convex.topup_account(test_account)
     convex.topup_account(other_account, 8000000)
     result = convex.send(contract, test_account)
-    contract_address = add_0x_prefix(result['value'])
+    contract_address = to_address(result['value'])
     convex.transfer(contract_address, 800000, other_account)
     convex.topup_account(test_account)
     result = convex.send(f'(call {contract_address} (tx-delay {other_account.address} 1000))', test_account)
